{******************************************************************}
{ part of DSPack 1.05                                                     }
{                                                                  }
{ home page : http://www.progdigy.com                              }
{ email     : hgourvest@progdigy.com                               }
{                                                                  }
{ date      : 20-11-2001                                           }
{                                                                  }
{ The contents of this file are used with permission, subject to   }
{ the Mozilla Public License Version 1.1 (the "License"); you may  }
{ not use this file except in compliance with the License. You may }
{ obtain a copy of the License at                                  }
{ http://www.mozilla.org/MPL/MPL-1.1.html                          }
{                                                                  }
{ Software distributed under the License is distributed on an      }
{ "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or   }
{ implied. See the License for the specific language governing     }
{ rights and limitations under the License.                        }
{                                                                  }
{ *****************************************************************}

unit FilterSelector;

interface
uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, DirectShow, DSPack, DSUtil, DSFilters, DesignEditors,
  DesignIntf;
  
type
  TFilterSelectorForm = class(TForm)
    Category: TComboBox;
    Filters: TListBox;
    Label1: TLabel;
    btOK: TButton;
    btCancel: TButton;
    Label2: TLabel;
    procedure FormCreate(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure CategoryChange(Sender: TObject);
    procedure FiltersClick(Sender: TObject);
    procedure btOKClick(Sender: TObject);
    procedure btCancelClick(Sender: TObject);
    procedure FiltersDblClick(Sender: TObject);
    procedure FormShow(Sender: TObject);
  public
    Enumerator: TDSSysDevEnum;
    CategoryGUID : TGUID;
    CategoryName : string;
    FilterGUID   : TGUID;
    FilterName   : string;
    Moniker      : string;
  end;

implementation

{$R *.dfm}

procedure TFilterSelectorForm.FormCreate(Sender: TObject);
var i: integer;
begin
  Enumerator := TDSSysDevEnum.Create;
  Category.Clear;
  for i := 0 to Enumerator.CountCategories - 1 do
    Category.Items.Add(Enumerator.Categories[i].FriendlyName);
end;

procedure TFilterSelectorForm.FormClose(Sender: TObject;
  var Action: TCloseAction);
begin
  Enumerator.Free;
end;

procedure TFilterSelectorForm.CategoryChange(Sender: TObject);
var i: integer;
begin
  if category.ItemIndex <> -1 then
  begin
    self.CategoryName := Enumerator.Categories[category.ItemIndex].FriendlyName;
    self.CategoryGUID := Enumerator.Categories[category.ItemIndex].CLSID;
    Enumerator.SelectIndexCategory(category.ItemIndex);
    Filters.Clear;
    if Enumerator.CountFilters <> -1 then
    for i := 0 to Enumerator.CountFilters -1 do
      Filters.Items.Add(Enumerator.Filters[i].FriendlyName);
  end;
end;

procedure TFilterSelectorForm.FiltersClick(Sender: TObject);
begin
  if Filters.ItemIndex <> -1 then
  begin
    Moniker      := Enumerator.Filters[Filters.ItemIndex].Moniker;
    FilterName   := Enumerator.Filters[Filters.ItemIndex].FriendlyName;
    FilterGUID   := Enumerator.Filters[Filters.ItemIndex].CLSID;
  end;
end;


procedure TFilterSelectorForm.btOKClick(Sender: TObject);
begin
  ModalResult := mrOK;
end;

procedure TFilterSelectorForm.btCancelClick(Sender: TObject);
begin
  ModalResult := mrCancel;
end;

procedure TFilterSelectorForm.FiltersDblClick(Sender: TObject);
begin
  if Filters.ItemIndex <> -1 then
  begin
    Moniker      := Enumerator.Filters[Filters.ItemIndex].Moniker;
    FilterName   := Enumerator.Filters[Filters.ItemIndex].FriendlyName;
    FilterGUID   := Enumerator.Filters[Filters.ItemIndex].CLSID;
    ModalResult  := mrOK;
  end;
end;

procedure TFilterSelectorForm.FormShow(Sender: TObject);
begin
  Category.ItemIndex := Category.Items.IndexOf(CategoryName);
  CategoryChange(nil);
  Filters.ItemIndex := Filters.Items.IndexOf(FilterName);
  self.FiltersClick(nil);
end;


end.
